A function that examines general equivalence theorem and return the maximum of drectional derivative as long as its associated design point.
verify_equiv(opt, space, opt_infor, t, g_part, infor_design, ...)A vector stands for a design point with its last entry being the maximum of directional derivative.
Integer. opt=0 means D-optimal, opt=1 means A-optimal.
Matrix. Design space, each row is a design point.
Matrix. Information matrix of current design.
Integer. Number of levels of treatment.
Matrix. Contrast matrix. Its column numbers must match the row number of information matrix.
Function. A function for calculating information matrix.
other necessary control parameters.